#!/usr/bin/env python3
#
#   Copyright 2018 - The Android Open Source Project
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""Apollo PS Keys and User Sink Events."""

# Persistent Store (PS) Keys from rio_all_merged.psr.

PSKEY = {
    'PSKEY_BDADDR': '0x0001',
    'PSKEY_DEVICE_NAME': '0x0108',
    'PSKEY_DEEP_SLEEP_STATE': '0x0229',
    'PSKEY_USB_VERSION': '0x02bc',
    'PSKEY_USB_DEVICE_CLASS_CODES': '0x02bd',
    'PSKEY_USB_VENDOR_ID': '0x02be',
    'PSKEY_USB_PRODUCT_ID': '0x02bf',
    'PSKEY_USB_PRODUCT_STRING': '0x02c2',
    'PSKEY_USB_SERIAL_NUMBER_STRING': '0x02c3',
    'PSKEY_EARCON_VERSION': '0x28b'
}

# Rio logging features from rio_log.h.

LOG_FEATURES = {
    'ALL': '0xffff',
    'VERBOSE': '0x0001',
    'TEST': '0x0002',
    'CSR': '0x0004',
    'DEBUG': '0x0008',
    'INFO': '0x0010',
    'ERROR': '0x0020',
    'TIME_STAMP': '0x0040',
}

# Supported events from sink_events.h."""

SINK_EVENTS = {
    'EventUsrMicOpen': '0x3206',
    'EventUsrMicClose': '0x3207',
    'EventUsrPowerOn': '0x4001',
    'EventUsrPowerOff': '0x4002',
    'EventUsrEnterPairing': '0x4003',
    'EventUsrInitateVoiceDial': '0x4004',
    'EventUsrInitateVoiceDial_AG2': '0x4005',
    'EventUsrLastNumberRedial': '0x4006',
    'EventUsrLastNumberRedial_AG2': '0x4007',
    'EventUsrAnswer': '0x4008',
    'EventUsrReject': '0x4009',
    'EventUsrCancelEnd': '0x400A',
    'EventUsrTransferToggle': '0x400B',
    'EventUsrMuteToggle': '0x400C',
    'EventUsrVolumeUp': '0x400D',
    'EventUsrVolumeDown': '0x400E',
    'EventUsrVolumeToggle': '0x400F',
    'EventUsrThreeWayReleaseAllHeld': '0x4010',
    'EventUsrThreeWayAcceptWaitingReleaseActive': '0x4011',
    'EventUsrThreeWayAcceptWaitingHoldActive': '0x4012',
    'EventUsrThreeWayAddHeldTo3Way': '0x4013',
    'EventUsrThreeWayConnect2Disconnect': '0x4014',
    'EventUsrLedsOnOffToggle': '0x4015',
    'EventUsrLedsOn': '0x4016',
    'EventUsrLedsOff': '0x4017',
    'EventUsrEstablishSLC': '0x4018',
    'EventUsrMuteOn': '0x4019',
    'EventUsrMuteOff': '0x401A',
    'EventUsrEnterTXContTestMode': '0x401B',
    'EventUsrEnterDUTState': '0x401C',
    'EventUsrBassBoostEnableDisableToggle': '0x401D',
    'EventUsrPlaceIncomingCallOnHold': '0x401E',
    'EventUsrAcceptHeldIncomingCall': '0x401F',
    'EventUsrRejectHeldIncomingCall': '0x4020',
    'EventUsrEnterDFUMode': '0x4021',
    'EventUsrEnterDriverlessDFUMode': '0x4022',
    'EventUsrEnterServiceMode': '0x4023',
    'EventUsrAudioPromptsOn': '0x4024',
    'EventUsrAudioPromptsOff': '0x4025',
    'EventUsrDialStoredNumber': '0x4026',
    'EventUsrUpdateStoredNumber': '0x4027',
    'EventUsrRestoreDefaults': '0x4028',
    'EventUsrConfirmationAccept': '0x4029',
    'EventUsrConfirmationReject': '0x402A',
    'EventUsrSelectAudioPromptLanguageMode': '0x402B',
    'EventUsrSwitchAudioMode': '0x402F',
    'EventUsrButtonLockingOn': '0x4030',
    'EventUsrButtonLockingOff': '0x4031',
    'EventUsrButtonLockingToggle': '0x4032',
    'EventUsrRssiPair': '0x4034',
    'EventUsrBassBoostOn': '0x4035',
    'EventUsrBassBoostOff': '0x4036',
    'EventUsr3DEnhancementOn': '0x4037',
    'EventUsr3DEnhancementOff': '0x4038',
    'EventUsrSelectAudioSourceNext': '0x4039',
    'EventUsrSelectAudioSourceAnalog': '0x403A',
    'EventUsrSelectAudioSourceUSB': '0x403B',
    'EventUsrSelectAudioSourceAG1': '0x403C',
    'EventUsrSelectAudioSourceAG2': '0x403D',
    'EventUsrSelectFMAudioSource': '0x403E',
    'EventUsrSelectAudioSourceNone': '0x403F',
    'EventUsrPbapDialIch': '0x4040',
    'EventUsrPbapDialMch': '0x4041',
    'EventUsrIntelligentPowerManagementOn': '0x4042',
    'EventUsrIntelligentPowerManagementOff': '0x4043',
    'EventUsrIntelligentPowerManagementToggle': '0x4044',
    'EventUsrAvrcpPlayPause': '0x4045',
    'EventUsrAvrcpStop': '0x4046',
    'EventUsrAvrcpSkipForward': '0x4047',
    'EventUsrAvrcpSkipBackward': '0x4048',
    'EventUsrAvrcpFastForwardPress': '0x4049',
    'EventUsrAvrcpFastForwardRelease': '0x404A',
    'EventUsrAvrcpRewindPress': '0x404B',
    'EventUsrAvrcpRewindRelease': '0x404C',
    'EventUsrAvrcpShuffleOff': '0x404D',
    'EventUsrAvrcpShuffleAllTrack': '0x404E',
    'EventUsrAvrcpShuffleGroup': '0x404F',
    'EventUsrAvrcpRepeatOff': '0x4050',
    'EventUsrAvrcpRepeatSingleTrack': '0x4051',
    'EventUsrAvrcpRepeatAllTrack': '0x4052',
    'EventUsrAvrcpRepeatGroup': '0x4053',
    'EventUsrAvrcpPlay': '0x4054',
    'EventUsrAvrcpPause': '0x4055',
    'EventUsrAvrcpToggleActive': '0x4056',
    'EventUsrAvrcpNextGroupPress': '0x4057',
    'EventUsrAvrcpPreviousGroupPress': '0x4058',
    'EventUsrPbapSetPhonebook': '0x4059',
    'EventUsrPbapBrowseEntry': '0x405A',
    'EventUsrPbapBrowseList': '0x405B',
    'EventUsrPbapDownloadPhonebook': '0x405C',
    'EventUsrPbapSelectPhonebookObject': '0x405D',
    'EventUsrPbapBrowseComplete': '0x405E',
    'EventUsrPbapGetPhonebookSize': '0x405F',
    'EventUsrUsbPlayPause': '0x4060',
    'EventUsrUsbStop': '0x4061',
    'EventUsrUsbFwd': '0x4062',
    'EventUsrUsbBack': '0x4063',
    'EventUsrUsbMute': '0x4064',
    'EventUsrUsbLowPowerMode': '0x4065',
    'EventUsrTestModeAudio': '0x4066',
    'EventUsrTestModeTone': '0x4067',
    'EventUsrTestModeKey': '0x4068',
    'EventUsrTestDefrag': '0x4069',
    'EventUsrDebugKeysToggle': '0x406A',
    'EventUsrSpeechRecognitionTuningStart': '0x406B',
    'EventUsrWbsTestSetCodecs': '0x406C',
    'EventUsrWbsTestOverrideResponse': '0x406D',
    'EventUsrWbsTestSetCodecsSendBAC': '0x406E',
    'EventUsrCreateAudioConnection': '0x406F',
    'EventUsrSwapA2dpMediaChannel': '0x407F',
    'EventUsrExternalMicConnected': '0x4080',
    'EventUsrExternalMicDisconnected': '0x4081',
    'EventUsrSSROn': '0x4082',
    'EventUsrSSROff': '0x4083',
    'EventUsrPeerSessionInquire': '0x4089',
    'EventUsrPeerSessionConnDisc': '0x408A',
    'EventUsrPeerSessionEnd': '0x408B',
    'EventUsrBatteryLevelRequest': '0x408C',
    'EventUsrVolumeOrientationNormal': '0x408D',
    'EventUsrVolumeOrientationInvert': '0x408E',
    'EventUsrResetPairedDeviceList': '0x408F',
    'EventUsrEnterDutMode': '0x4090',
    'EventUsr3DEnhancementEnableDisableToggle': '0x4091',
    'EventUsrRCVolumeUp': '0x4092',
    'EventUsrRCVolumeDown': '0x4093',
    'EventUsrEnterBootMode2': '0x4094',
    'EventUsrChargerConnected': '0x4095',
    'EventUsrChargerDisconnected': '0x4096',
    'EventUsrSubwooferDisconnect': '0x4097',
    'EventUsrAnalogAudioConnected': '0x4098',
    'EventUsrAnalogAudioDisconnected': '0x4099',
    'EventUsrGaiaDFURequest': '0x409A',
    'EventUsrStartIRLearningMode': '0x409B',
    'EventUsrStopIRLearningMode': '0x409C',
    'EventUsrClearIRCodes': '0x409D',
    'EventUsrUserEqOn': '0x409E',
    'EventUsrUserEqOff': '0x409F',
    'EventUsrUserEqOnOffToggle': '0x40A0',
    'EventUsrSpdifAudioConnected': '0x40AD',
    'EventUsrSpdifAudioDisconnected': '0x40AE',
    'EventUsrSelectAudioSourceSpdif': '0x40AF',
    'EventUsrChangeAudioRouting': '0x40B0',
    'EventUsrMasterDeviceTrimVolumeUp': '0x40B1',
    'EventUsrMasterDeviceTrimVolumeDown': '0x40B2',
    'EventUsrSlaveDeviceTrimVolumeUp': '0x40B3',
    'EventUsrSlaveDeviceTrimVolumeDown': '0x40B4',
    'EventUsrEstablishPeerConnection': '0x40B5',
    'EventUsrTwsQualificationEnablePeerOpen': '0x40B7',
    'EventUsrBleStartBonding': '0x40D0',
    'EventUsrBleSwitchPeripheral': '0x40D1',
    'EventUsrBleSwitchCentral': '0x40D2',
    'EventUsrImmAlertStop': '0x40D3',
    'EventUsrLlsAlertStop': '0x40D4',
    'EventUsrFindMyRemoteImmAlertMild': '0x40D5',
    'EventUsrFindMyRemoteImmAlertHigh': '0x40D6',
    'EventUsrFindMyPhoneImmAlertMild': '0x40D7',
    'EventUsrFindMyPhoneImmAlertHigh': '0x40D8',
    'EventUsrFindMyPhoneRemoteImmAlertHigh': '0x40D9',
    'EventUsrPartyModeOn': '0x40DA',
    'EventUsrPartyModeOff': '0x40DB',
    'EventUsrBleDeleteDevice': '0x40EC',
    'EventUsrAvrcpNextGroupRelease': '0x40ED',
    'EventUsrAvrcpPreviousGroupRelease': '0x40EE',
    'EventUsrTwsQualificationVolUp': '0x40EF',
    'EventUsrTwsQualificationVolDown': '0x40F0',
    'EventUsrStartA2DPStream': '0x40F1',
    'EventUsrPbapBrowseListByName': '0x40F2',
    'EventUsrTwsQualificationSetAbsVolume': '0x40F3',
    'EventUsrTwsQualificationPlayTrack': '0x40F4',
    'EventUsrBleHidExtraConfig': '0x40F5',
    'EventUsrTwsQualificationAVRCPConfigureDataSize': '0x40F6',
}
