#!/usr/bin/env python3
#
#   Copyright 2020 - The Android Open Source Project
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

from acts.controllers.fuchsia_lib.base_lib import BaseLib


class FuchsiaSysInfoLib(BaseLib):
    def __init__(self, addr, tc, client_id):
        self.address = addr
        self.test_counter = tc
        self.client_id = client_id

    def getBoardName(self):
        """ Gets the board name for the platform we're running on.

        Returns:
            String, board name, prints an error message if error.
        """
        test_cmd = "sysinfo_facade.GetBoardName"
        test_args = {}
        test_id = self.build_id(self.test_counter)
        self.test_counter += 1

        return self.send_command(test_id, test_cmd, test_args)

    def getBoardRevision(self):
        """ Gets the board revision (hw_id) for the platform we're running on.

        Returns:
            uint32, revision/hw_id, prints an error message if error.
        """
        test_cmd = "sysinfo_facade.GetBoardRevision"
        test_args = {}
        test_id = self.build_id(self.test_counter)
        self.test_counter += 1

        return self.send_command(test_id, test_cmd, test_args)

    def getBootloaderVendor(self):
        """ Gets the board vendor for the platform we're running on.

        Returns:
            String, bootloader vendor, prints an error message if error.
        """
        test_cmd = "sysinfo_facade.GetBootloaderVendor"
        test_args = {}
        test_id = self.build_id(self.test_counter)
        self.test_counter += 1

        return self.send_command(test_id, test_cmd, test_args)
